EditArea

[__CSSRULES__] [__JSCODE__]
[__TOOLBAR__]

{$position}: | {$line_abbr} 0, {$char_abbr} 0 | {$total}: | {$line_abbr} 0, {$char_abbr} 0 |

{$processing}

{$search} |  |
{$replace} |  |

{$match_case} {$reg_exp}
{$find_next} {$replace} {$replace_all}

## Editarea [__EA_VERSION__]

### {$shortcuts}:

{$tab}: {$add_tab}
{$shift}+{$tab}: {$remove_tab}
{$ctrl}+f: {$search_command}
{$ctrl}+r: {$replace_command}
{$ctrl}+h: {$highlight}
{$ctrl}+g: {$go_to_line}
{$ctrl}+z: {$undo}
{$ctrl}+y: {$redo}
{$ctrl}+e: {$help}
{$ctrl}+q, {$esc}: {$close_popup}
{$accesskey} E: {$toggle}
{$about_notice}
© Christophe Dolivet - 2007